@@ -72,7 +72,9 @@ class Database extends AbstractData
             // set default options
             $options['opt'][PDO::ATTR_ERRMODE]          = PDO::ERRMODE_EXCEPTION;
             $options['opt'][PDO::ATTR_EMULATE_PREPARES] = false;
-            $options['opt'][PDO::ATTR_PERSISTENT]       = true;
+            if (!array_key_exists(PDO::ATTR_PERSISTENT, $options['opt'])) {
+                $options['opt'][PDO::ATTR_PERSISTENT] = true;
+            }
             $db_tables_exist                            = true;
 
             // setup type and dabase connection
@@ -138,54 +140,27 @@ class Database extends AbstractData
      * @param  array  $paste
      * @return bool
      */
-    public function create($pasteid, array $paste)
+    public function create($pasteid, array &$paste)
     {
         $expire_date      = 0;
-        $opendiscussion   = $burnafterreading = false;
-        $attachment       = $attachmentname   = null;
         $meta             = $paste['meta'];
-        $isVersion1       = array_key_exists('data', $paste);
         if (array_key_exists('expire_date', $meta)) {
             $expire_date = (int) $meta['expire_date'];
             unset($meta['expire_date']);
         }
-        if (array_key_exists('opendiscussion', $meta)) {
-            $opendiscussion = $meta['opendiscussion'];
-            unset($meta['opendiscussion']);
-        }
-        if (array_key_exists('burnafterreading', $meta)) {
-            $burnafterreading = $meta['burnafterreading'];
-            unset($meta['burnafterreading']);
-        }
-        if ($isVersion1) {
-            if (array_key_exists('attachment', $meta)) {
-                $attachment = $meta['attachment'];
-                unset($meta['attachment']);
-            }
-            if (array_key_exists('attachmentname', $meta)) {
-                $attachmentname = $meta['attachmentname'];
-                unset($meta['attachmentname']);
-            }
-        } else {
-            $opendiscussion   = $paste['adata'][2];
-            $burnafterreading = $paste['adata'][3];
-        }
         try {
             return $this->_exec(
                 'INSERT INTO "' . $this->_sanitizeIdentifier('paste') .
-                '" VALUES(?,?,?,?,?,?,?,?)',
+                '" VALUES(?,?,?,?)',
                 array(
                     $pasteid,
-                    $isVersion1 ? $paste['data'] : Json::encode($paste),
+                    Json::encode($paste),
                     $expire_date,
-                    (int) $opendiscussion,
-                    (int) $burnafterreading,
                     Json::encode($meta),
-                    $attachment,
-                    $attachmentname,
                 )
             );
         } catch (Exception $e) {
+            error_log('Error while attempting to insert a paste into the database: ' . $e->getMessage());
             return false;
         }
     }
@@ -211,38 +186,17 @@ class Database extends AbstractData
             return false;
         }
         // create array
-        $data       = Json::decode($row['data']);
-        $isVersion2 = array_key_exists('v', $data) && $data['v'] >= 2;
-        $paste      = $isVersion2 ? $data : array('data' => $row['data']);
+        $paste = Json::decode($row['data']);
 
         try {
-            $row['meta'] = Json::decode($row['meta']);
+            $paste['meta'] = Json::decode($row['meta']);
         } catch (Exception $e) {
-            $row['meta'] = array();
+            $paste['meta'] = array();
         }
-        $row                        = self::upgradePreV1Format($row);
-        $paste['meta']              = $row['meta'];
-        $expire_date                = (int) $row['expiredate'];
+        $expire_date = (int) $row['expiredate'];
         if ($expire_date > 0) {
             $paste['meta']['expire_date'] = $expire_date;
         }
-        if ($isVersion2) {
-            return $paste;
-        }
-
-        // support v1 attachments
-        if (array_key_exists('attachment', $row) && !empty($row['attachment'])) {
-            $paste['attachment'] = $row['attachment'];
-            if (array_key_exists('attachmentname', $row) && !empty($row['attachmentname'])) {
-                $paste['attachmentname'] = $row['attachmentname'];
-            }
-        }
-        if ($row['opendiscussion']) {
-            $paste['meta']['opendiscussion'] = true;
-        }
-        if ($row['burnafterreading']) {
-            $paste['meta']['burnafterreading'] = true;
-        }
 
         return $paste;
     }
@@ -295,38 +249,33 @@ class Database extends AbstractData
      * @param  array  $comment
      * @return bool
      */
-    public function createComment($pasteid, $parentid, $commentid, array $comment)
+    public function createComment($pasteid, $parentid, $commentid, array &$comment)
     {
-        if (array_key_exists('data', $comment)) {
-            $version = 1;
-            $data    = $comment['data'];
-        } else {
-            $version = 2;
-            $data    = Json::encode($comment);
+        try {
+            $data = Json::encode($comment);
+        } catch (Exception $e) {
+            error_log('Error while attempting to insert a comment into the database: ' . $e->getMessage());
+            return false;
         }
-        list($createdKey, $iconKey) = $this->_getVersionedKeys($version);
-        $meta                       = $comment['meta'];
-        unset($comment['meta']);
-        foreach (array('nickname', $iconKey) as $key) {
-            if (!array_key_exists($key, $meta)) {
-                $meta[$key] = null;
-            }
+        $meta = $comment['meta'];
+        if (!array_key_exists('icon', $meta)) {
+            $meta['icon'] = null;
         }
         try {
             return $this->_exec(
                 'INSERT INTO "' . $this->_sanitizeIdentifier('comment') .
-                '" VALUES(?,?,?,?,?,?,?)',
+                '" VALUES(?,?,?,?,?,?)',
                 array(
                     $commentid,
                     $pasteid,
                     $parentid,
                     $data,
-                    $meta['nickname'],
-                    $meta[$iconKey],
-                    $meta[$createdKey],
+                    $meta['icon'],
+                    $meta['created'],
                 )
             );
         } catch (Exception $e) {
+            error_log('Error while attempting to insert a comment into the database: ' . $e->getMessage());
             return false;
         }
     }
@@ -347,25 +296,15 @@ class Database extends AbstractData
 
         // create comment list
         $comments = array();
-        if (is_array($rows) && count($rows)) {
+        if (count($rows)) {
             foreach ($rows as $row) {
-                $i    = $this->getOpenSlot($comments, (int) $row['postdate']);
-                $data = Json::decode($row['data']);
-                if (array_key_exists('v', $data) && $data['v'] >= 2) {
-                    $version      = 2;
-                    $comments[$i] = $data;
-                } else {
-                    $version      = 1;
-                    $comments[$i] = array('data' => $row['data']);
-                }
-                list($createdKey, $iconKey) = $this->_getVersionedKeys($version);
+                $i                          = $this->getOpenSlot($comments, (int) $row['postdate']);
+                $comments[$i]               = Json::decode($row['data']);
                 $comments[$i]['id']         = $row['dataid'];
                 $comments[$i]['parentid']   = $row['parentid'];
-                $comments[$i]['meta']       = array($createdKey => (int) $row['postdate']);
-                foreach (array('nickname' => 'nickname', 'vizhash' => $iconKey) as $rowKey => $commentKey) {
-                    if (array_key_exists($rowKey, $row) && !empty($row[$rowKey])) {
-                        $comments[$i]['meta'][$commentKey] = $row[$rowKey];
-                    }
+                $comments[$i]['meta']       = array('created' => (int) $row['postdate']);
+                if (array_key_exists('vizhash', $row) && !empty($row['vizhash'])) {
+                    $comments[$i]['meta']['icon'] = $row['vizhash'];
                 }
             }
             ksort($comments);
@@ -447,7 +386,7 @@ class Database extends AbstractData
                 $fs    = new Filesystem(array('dir' => 'data'));
                 $value = $fs->getValue('salt');
                 $this->setValue($value, 'salt');
-                @unlink($file);
+                unlink($file);
                 return $value;
             }
         }
@@ -504,8 +443,8 @@ class Database extends AbstractData
     private function _exec($sql, array $params)
     {
         $statement = $this->_db->prepare($sql);
-        foreach ($params as $key => &$parameter) {
-            $position = $key + 1;
+        $position  = 1;
+        foreach ($params as &$parameter) {
             if (is_int($parameter)) {
                 $statement->bindParam($position, $parameter, PDO::PARAM_INT);
             } elseif (is_string($parameter) && strlen($parameter) >= 4000) {
@@ -513,6 +452,7 @@ class Database extends AbstractData
             } else {
                 $statement->bindParam($position, $parameter);
             }
+            ++$position;
         }
         $result = $statement->execute();
         $statement->closeCursor();
@@ -527,7 +467,7 @@ class Database extends AbstractData
      * @param  array $params
      * @param  bool $firstOnly if only the first row should be returned
      * @throws PDOException
-     * @return array|false
+     * @return array
      */
     private function _select($sql, array $params, $firstOnly = false)
     {
@@ -535,6 +475,10 @@ class Database extends AbstractData
         $statement->execute($params);
         if ($firstOnly) {
             $result = $statement->fetch(PDO::FETCH_ASSOC);
+            if ($this->_type === 'oci' && is_array($result)) {
+                // returned CLOB values are streams, convert these into strings
+                $result = array_map('PrivateBin\Data\Database::_sanitizeClob', $result);
+            }
         } elseif ($this->_type === 'oci') {
             // workaround for https://bugs.php.net/bug.php?id=46728
             $result = array();
@@ -545,30 +489,9 @@ class Database extends AbstractData
             $result = $statement->fetchAll(PDO::FETCH_ASSOC);
         }
         $statement->closeCursor();
-        if ($this->_type === 'oci' && is_array($result)) {
-            // returned CLOB values are streams, convert these into strings
-            $result = $firstOnly ?
-                array_map('PrivateBin\Data\Database::_sanitizeClob', $result) :
-                $result;
-        }
         return $result;
     }
 
-    /**
-     * get version dependent key names
-     *
-     * @access private
-     * @param  int $version
-     * @return array
-     */
-    private function _getVersionedKeys($version)
-    {
-        if ($version === 1) {
-            return array('postdate', 'vizhash');
-        }
-        return array('created', 'icon');
-    }
-
     /**
      * get table list query, depending on the database type
      *
@@ -598,18 +521,8 @@ class Database extends AbstractData
                 $sql = 'SELECT table_name FROM all_tables';
                 break;
             case 'pgsql':
-                $sql = 'SELECT c."relname" AS "table_name" '
-                     . 'FROM "pg_class" c, "pg_user" u '
-                     . 'WHERE c."relowner" = u."usesysid" AND c."relkind" = \'r\' '
-                     . 'AND NOT EXISTS (SELECT 1 FROM "pg_views" WHERE "viewname" = c."relname") '
-                     . "AND c.\"relname\" !~ '^(pg_|sql_)' "
-                     . 'UNION '
-                     . 'SELECT c."relname" AS "table_name" '
-                     . 'FROM "pg_class" c '
-                     . "WHERE c.\"relkind\" = 'r' "
-                     . 'AND NOT EXISTS (SELECT 1 FROM "pg_views" WHERE "viewname" = c."relname") '
-                     . 'AND NOT EXISTS (SELECT 1 FROM "pg_user" WHERE "usesysid" = c."relowner") '
-                     . "AND c.\"relname\" !~ '^pg_'";
+                $sql = 'SELECT "tablename" FROM "pg_catalog"."pg_tables" '
+                     . 'WHERE "schemaname" NOT IN (\'pg_catalog\', \'information_schema\')';
                 break;
             case 'sqlite':
                 $sql = 'SELECT "name" FROM "sqlite_master" WHERE "type"=\'table\' '
@@ -732,7 +645,6 @@ class Database extends AbstractData
     private function _createPasteTable()
     {
         list($main_key, $after_key) = $this->_getPrimaryKeyClauses();
-        $dataType                   = $this->_getDataType();
         $attachmentType             = $this->_getAttachmentType();
         $metaType                   = $this->_getMetaType();
         $this->_db->exec(
@@ -740,16 +652,12 @@ class Database extends AbstractData
             "\"dataid\" CHAR(16) NOT NULL$main_key, " .
             "\"data\" $attachmentType, " .
             '"expiredate" INT, ' .
-            '"opendiscussion" INT, ' .
-            '"burnafterreading" INT, ' .
-            "\"meta\" $metaType, " .
-            "\"attachment\" $attachmentType, " .
-            "\"attachmentname\" $dataType$after_key )"
+            "\"meta\" $metaType$after_key )"
         );
     }
 
     /**
-     * create the paste table
+     * create the comment table
      *
      * @access private
      */
@@ -763,7 +671,6 @@ class Database extends AbstractData
             '"pasteid" CHAR(16), ' .
             '"parentid" CHAR(16), ' .
             "\"data\" $dataType, " .
-            "\"nickname\" $dataType, " .
             "\"vizhash\" $dataType, " .
             "\"postdate\" INT$after_key )"
         );
@@ -792,7 +699,7 @@ class Database extends AbstractData
     }
 
     /**
-     * create the paste table
+     * create the config table
      *
      * @access private
      */
@@ -842,6 +749,26 @@ class Database extends AbstractData
         return preg_replace('/[^A-Za-z0-9_]+/', '', $this->_prefix . $identifier);
     }
 
+    /**
+     * check if the current database type supports dropping columns
+     *
+     * @access private
+     * @return bool
+     */
+    private function _supportsDropColumn()
+    {
+        $supportsDropColumn = true;
+        if ($this->_type === 'sqlite') {
+            try {
+                $row                = $this->_select('SELECT sqlite_version() AS "v"', array(), true);
+                $supportsDropColumn = (bool) version_compare($row['v'], '3.35.0', '>=');
+            } catch (PDOException $e) {
+                $supportsDropColumn = false;
+            }
+        }
+        return $supportsDropColumn;
+    }
+
     /**
      * upgrade the database schema from an old version
      *
@@ -913,22 +840,37 @@ class Database extends AbstractData
             }
         }
         if (version_compare($oldversion, '1.7.1', '<=')) {
-            $supportsDropColumn = true;
-            if ($this->_type === 'sqlite') {
-                try {
-                    $row                = $this->_select('SELECT sqlite_version() AS "v"', array(), true);
-                    $supportsDropColumn = version_compare($row['v'], '3.35.0', '>=');
-                } catch (PDOException $e) {
-                    $supportsDropColumn = false;
-                }
-            }
-            if ($supportsDropColumn) {
+            if ($this->_supportsDropColumn()) {
                 $this->_db->exec(
                     'ALTER TABLE "' . $this->_sanitizeIdentifier('paste') .
                     '" DROP COLUMN "postdate"'
                 );
             }
         }
+        if (version_compare($oldversion, '1.7.8', '<=')) {
+            if ($this->_supportsDropColumn()) {
+                $this->_db->exec(
+                    'ALTER TABLE "' . $this->_sanitizeIdentifier('paste') .
+                    '" DROP COLUMN "opendiscussion"'
+                );
+                $this->_db->exec(
+                    'ALTER TABLE "' . $this->_sanitizeIdentifier('paste') .
+                    '" DROP COLUMN "burnafterreading"'
+                );
+                $this->_db->exec(
+                    'ALTER TABLE "' . $this->_sanitizeIdentifier('paste') .
+                    '" DROP COLUMN "attachment"'
+                );
+                $this->_db->exec(
+                    'ALTER TABLE "' . $this->_sanitizeIdentifier('paste') .
+                    '" DROP COLUMN "attachmentname"'
+                );
+                $this->_db->exec(
+                    'ALTER TABLE "' . $this->_sanitizeIdentifier('comment') .
+                    '" DROP COLUMN "nickname"'
+                );
+            }
+        }
         $this->_exec(
             'UPDATE "' . $this->_sanitizeIdentifier('config') .
             '" SET "value" = ? WHERE "id" = ?',
